@@ -40,7 +40,7 @@ class SphinxAdapter(ClassicAdapter):
     - The reason message is obviously added in the directive block if not empty.
     """
 
-    def __init__(self, directive, reason="", version="", action='always', category=DeprecationWarning):
+    def __init__(self, directive, reason="", version="", action=None, category=DeprecationWarning):
         """
         Construct a wrapper adapter.
 
@@ -62,7 +62,8 @@ class SphinxAdapter(ClassicAdapter):
         :param action:
             A warning filter used to activate or not the deprecation warning.
             Can be one of "error", "ignore", "always", "default", "module", or "once".
-            By default the deprecation warning is always emitted (the value is "always").
+            If ``None`` or empty, the the global filtering mechanism is used.
+            See: `The Warnings Filter`_ in the Python documentation.
 
         :type  category: type
         :param category:
@@ -82,8 +83,9 @@ class SphinxAdapter(ClassicAdapter):
         :return: the decorated class or function.
         """
         reason = textwrap.dedent(self.reason).strip()
-        reason = '\n'.join(textwrap.fill(line, width=70, initial_indent='   ', subsequent_indent='   ')
-                           for line in reason.splitlines()).strip()
+        reason = '\n'.join(
+            textwrap.fill(line, width=70, initial_indent='   ', subsequent_indent='   ') for line in reason.splitlines()
+        ).strip()
         docstring = textwrap.dedent(wrapped.__doc__ or "")
         if docstring:
             docstring += "\n\n"
@@ -169,7 +171,7 @@ def deprecated(*args, **kwargs):
     -   "action":
         A warning filter used to activate or not the deprecation warning.
         Can be one of "error", "ignore", "always", "default", "module", or "once".
-        By default the deprecation warning is always emitted (the value is "always").
+        If ``None``, empty or missing, the the global filtering mechanism is used.
 
     -   "category":
         The warning category to use for the deprecation warning.
@@ -180,7 +182,4 @@ def deprecated(*args, **kwargs):
     """
     directive = kwargs.pop('directive', 'deprecated')
     adapter_cls = kwargs.pop('adapter_cls', SphinxAdapter)
-    return _classic_deprecated(*args,
-                               directive=directive,
-                               adapter_cls=adapter_cls,
-                               **kwargs)
+    return _classic_deprecated(*args, directive=directive, adapter_cls=adapter_cls, **kwargs)
